Array API Standard Support: ``linalg.interpolative``
====================================================

.. _array_api_support_linalg_interpolative_cpu:

Support on CPU
--------------

.. array-api-support-per-function::
    :module: linalg.interpolative
    :backend_type: cpu

.. _array_api_support_linalg_interpolative_gpu:

Support on GPU
--------------

.. array-api-support-per-function::
    :module: linalg.interpolative
    :backend_type: gpu

.. _array_api_support_linalg_interpolative_jit:

Support with JIT
----------------

.. array-api-support-per-function::
    :module: linalg.interpolative
    :backend_type: jit
